#****************************************************************************
#**
#**  Author(s):  Pheonix-IV
#**
#**  Summary  :  Residence Script
#**
#**  Copyright  2007 Firebird Industries.  All rights reserved.
#****************************************************************************

local TEnergyCreationUnit = import('/lua/terranunits.lua').TEnergyCreationUnit

IUB1101 = Class(TEnergyCreationUnit) {
OnStartBuild = function(self, unitBeingBuilt, order ) 
        TEnergyCreationUnit.OnStartBuild(self,unitBeingBuilt, order) 
        local unitid = self:GetBlueprint().General.UpgradesTo 
        self.UnitBeingBuilt = unitBeingBuilt 
        if unitBeingBuilt:GetUnitId() == unitid and order == 'Upgrade' then 
            ChangeState(self, self.UpgradingState) 
        end 
    end, 

UpgradingState = State { 
        Main = function(self) 
            self:StopRocking() 
            local bp = self:GetBlueprint().Display 
            self:PlayUnitSound('UpgradeStart') 
            self:DisableDefaultToggleCaps() 
            if bp.AnimationUpgrade then 
                local unitBuilding = self.UnitBeingBuilt 
                self.AnimatorUpgradeManip = CreateAnimator(self) 
                self.Trash:Add(self.AnimatorUpgradeManip) 
                local fractionOfComplete = 0 
                self:StartUpgradeEffects(unitBuilding) 
                self.AnimatorUpgradeManip:PlayAnim(bp.AnimationUpgrade, false):SetRate(0) 

                while fractionOfComplete < 1 and not self:IsDead() do 
                    fractionOfComplete = unitBuilding:GetFractionComplete() 
                    self.AnimatorUpgradeManip:SetAnimationFraction(fractionOfComplete) 
                    WaitTicks(1) 
                end 
                if not self:IsDead() then 
                    self.AnimatorUpgradeManip:SetRate(1) 
                end 
            end 
        end, 

        OnStopBuild = function(self, unitBuilding) 
            TEnergyCreationUnit.OnStopBuild(self, unitBuilding) 
            self:EnableDefaultToggleCaps() 
            if unitBuilding:GetFractionComplete() == 1 then 
                NotifyUpgrade(self, unitBuilding) 
                self:StopUpgradeEffects(unitBuilding) 
                self:PlayUnitSound('UpgradeEnd') 
                self:Destroy() 
            end 
        end, 

        OnFailedToBuild = function(self) 
            TEnergyCreationUnit.OnFailedToBuild(self) 
            self:EnableDefaultToggleCaps() 
            self.AnimatorUpgradeManip:Destroy() 
            if self:GetCurrentLayer() == 'Water' then 
                self:StartRocking() 
            end 
            self:PlayUnitSound('UpgradeFailed') 
            self:PlayActiveAnimation() 
            ChangeState(self, self.IdleState) 
        end, 
        
    }, 

StartUpgradeEffects = function(self, unitBeingBuilt) 
        unitBeingBuilt:HideBone(0, true) 
    end, 
    
    StopUpgradeEffects = function(self, unitBeingBuilt) 
        unitBeingBuilt:ShowBone(0, true) 
    end, 

}

TypeClass = IUB1101